@@ -88,6 +88,8 @@ keyboard* kb_new(Window win, Display *display, int kb_x, int kb_y,
 {
   keyboard *kb = NULL;
 
+  int height_tmp = 0;
+
   list *listp;
   
   int max_width = 0; /* required for sizing code */
@@ -201,7 +203,7 @@ keyboard* kb_new(Window win, Display *display, int kb_x, int kb_y,
   kb->state_locked     = KB_STATE_NORMAL;
   kb->theme            = rounded;
   kb->slide_margin     = 0;
-  kb->key_delay_repeat = 10;
+  kb->key_delay_repeat = 40;
   kb->key_repeat       = 5;
   
   kb->total_layouts = 0;
@@ -378,6 +380,8 @@ keyboard* kb_new(Window win, Display *display, int kb_x, int kb_y,
 		     if (!kb->vbox->act_height) 
 			kb->vbox->act_height = atoi(tmpstr_C);
 		    */
+
+                    height_tmp = atoi(tmpstr_C);
 		  }
 		else if (strcmp(tmpstr_A, "slide_margin") == 0)
 		  {
@@ -497,7 +501,8 @@ keyboard* kb_new(Window win, Display *display, int kb_x, int kb_y,
   fclose(rcfp);
 
   kb->vbox = kb->kbd_layouts[0];
-
+  if(height_tmp)
+    kb->vbox->act_height = height_tmp;
   /* pass 1 - calculate min dimentions  */
   
   listp = kb->vbox->root_kid;
